@@ -30,6 +30,7 @@ from gribapi import (
     codes_any_new_from_samples,
     codes_bufr_copy_data,
     codes_bufr_extract_headers,
+    codes_bufr_key_is_coordinate,
     codes_bufr_key_is_header,
     codes_bufr_keys_iterator_delete,
     codes_bufr_keys_iterator_get_name,
@@ -64,6 +65,7 @@ from gribapi import grib_get_double_array as codes_get_double_array
 from gribapi import grib_get_double_element as codes_get_double_element
 from gribapi import grib_get_double_elements as codes_get_double_elements
 from gribapi import grib_get_elements as codes_get_elements
+from gribapi import grib_get_float_array as codes_get_float_array
 from gribapi import grib_get_long as codes_get_long
 from gribapi import grib_get_long_array as codes_get_long_array
 from gribapi import grib_get_message as codes_get_message
@@ -226,6 +228,7 @@ __all__ = [
     "codes_bufr_copy_data",
     "codes_bufr_extract_headers",
     "codes_bufr_key_is_header",
+    "codes_bufr_key_is_coordinate",
     "codes_bufr_keys_iterator_delete",
     "codes_bufr_keys_iterator_get_name",
     "codes_bufr_keys_iterator_new",
@@ -249,6 +252,7 @@ __all__ = [
     "codes_get_double_elements",
     "codes_get_double",
     "codes_get_elements",
+    "codes_get_float_array",
     "codes_get_gaussian_latitudes",
     "codes_get_library_path",
     "codes_get_long_array",
