@@ -100,10 +100,15 @@ class Message:
         if check_values:
             # Check values just set
             for name, value in key_values.items():
-                saved_value = self.get(name)
                 cast_value = value
-                if not isinstance(value, type(saved_value)):
-                    cast_value = type(saved_value)(value)
+                if isinstance(value, str):
+                    saved_value = eccodes.codes_get_string(self._handle, name)
+                elif isinstance(value, int):
+                    saved_value = eccodes.codes_get_long(self._handle, name)
+                else:
+                    saved_value = self.get(name)
+                    if not isinstance(value, type(saved_value)):
+                        cast_value = type(saved_value)(value)
                 if saved_value != cast_value:
                     raise ValueError(
                         f"Unexpected retrieved value {saved_value} for key {name}. Expected {cast_value}"
