@@ -20,7 +20,7 @@ Numpy is a package used for scientific computing in Python and an efficient cont
 
 @em Requirements:
 
-    - Python 3.7 or higher
+    - Python 3.8 or higher
     - NumPy
 
 """
@@ -46,11 +46,7 @@ except NameError:
     file = io.IOBase
     long = int
 
-KEYTYPES = {
-    1: int,
-    2: float,
-    3: str,
-}
+KEYTYPES = {1: int, 2: float, 3: str, 4: bytes}
 
 CODES_PRODUCT_ANY = 0
 """ Generic product kind """
@@ -1163,6 +1159,8 @@ def grib_set_double_array(msgid, key, inarray):
     length = len(inarray)
     if isinstance(inarray, np.ndarray):
         nd = inarray
+        # ECC-1555
+        length = inarray.size
         if length > 0:
             if not isinstance(nd[0], float):
                 # ECC-1042: input array of integers
@@ -1197,6 +1195,26 @@ def grib_get_double_array(msgid, key):
     return arr
 
 
+@require(msgid=int, key=str)
+def grib_get_float_array(msgid, key):
+    """
+    @brief Get the value of the key as a NumPy array of floats.
+
+    @param msgid   id of the message loaded in memory
+    @param key     key name
+    @return        numpy.ndarray
+    @exception CodesInternalError
+    """
+    h = get_handle(msgid)
+    nval = grib_get_size(msgid, key)
+    length_p = ffi.new("size_t*", nval)
+    arr = np.empty((nval,), dtype="float32")
+    vals_p = ffi.cast("float *", arr.ctypes.data)
+    err = lib.grib_get_float_array(h, key.encode(ENC), vals_p, length_p)
+    GRIB_CHECK(err)
+    return arr
+
+
 # See ECC-1246
 def _decode_bytes(binput, maxlen=None):
     if maxlen:
@@ -1925,7 +1943,7 @@ def grib_get_native_type(msgid, key):
     """
     @brief Retrieve the native type of a key.
 
-    Possible values can be int, float or string.
+    Possible values can be int, float or str.
 
     @param msgid   id of the message loaded in memory
     @param key     key we want to find out the type for
@@ -1949,7 +1967,7 @@ def grib_get(msgid, key, ktype=None):
 
     The type of value returned depends on the native type of the requested key.
     The type of value returned can be forced by using the type argument of the
-    function. The type argument can be int, float or str.
+    function. The ktype argument can be int, float, str or bytes.
 
     The \em msgid references a message loaded in memory.
 
@@ -1959,7 +1977,7 @@ def grib_get(msgid, key, ktype=None):
 
     @param msgid      id of the message loaded in memory
     @param key        key name
-    @param ktype      the type we want the output in (int, float or str), native type if not specified
+    @param ktype      the type we want the output in, native type if not specified
     @return           scalar value of key as int, float or str
     @exception CodesInternalError
     """
@@ -1976,6 +1994,8 @@ def grib_get(msgid, key, ktype=None):
         result = grib_get_double(msgid, key)
     elif ktype is str:
         result = grib_get_string(msgid, key)
+    elif ktype is bytes:
+        result = grib_get_string(msgid, key)
 
     return result
 
@@ -1987,13 +2007,13 @@ def grib_get_array(msgid, key, ktype=None):
 
     The type of the array returned depends on the native type of the requested key.
     For numeric data, the output array will be stored in a NumPy ndarray.
-    The type of value returned can be forced by using the type argument of the function.
-    The type argument can be int, float or string.
+    The type of value returned can be forced by using the ktype argument of the function.
+    The ktype argument can be int, float, float32, float64, str or bytes.
 
-    @param msgid      id of the message loaded in memory
-    @param key        the key to get the value for
-    @param ktype      the type we want the output in (can be int, float or string), native type if not specified
-    @return           numpy.ndarray
+    @param msgid  id of the message loaded in memory
+    @param key    the key to get the value for
+    @param ktype  the type we want the output in, native type if not specified
+    @return       numpy.ndarray or None
     @exception CodesInternalError
     """
     if ktype is None:
@@ -2002,16 +2022,20 @@ def grib_get_array(msgid, key, ktype=None):
     result = None
     if ktype is int:
         result = grib_get_long_array(msgid, key)
-    elif ktype is float:
+    elif ktype is float or ktype is np.float64:
         result = grib_get_double_array(msgid, key)
+    elif ktype is np.float32:
+        result = grib_get_float_array(msgid, key)
     elif ktype is str:
         result = grib_get_string_array(msgid, key)
+    elif ktype is bytes:
+        result = grib_get_string_array(msgid, key)
 
     return result
 
 
 @require(gribid=int)
-def grib_get_values(gribid):
+def grib_get_values(gribid, ktype=float):
     """
     @brief Retrieve the contents of the 'values' key for a GRIB message.
 
@@ -2019,11 +2043,23 @@ def grib_get_values(gribid):
 
     \b Examples: \ref grib_print_data.py "grib_print_data.py", \ref grib_samples.py "grib_samples.py"
 
-    @param gribid   id of the GRIB loaded in memory
-    @return         numpy.ndarray
+    @param gribid    id of the GRIB loaded in memory
+    @param ktype     data type of the result: numpy.float32 or numpy.float64
+    @return          numpy.ndarray
     @exception CodesInternalError
     """
-    return grib_get_double_array(gribid, "values")
+    result = None
+
+    if ktype is np.float32:
+        result = grib_get_float_array(gribid, "values")
+    elif ktype is np.float64 or ktype is float:
+        result = grib_get_double_array(gribid, "values")
+    else:
+        raise TypeError(
+            f"Unsupported data type {ktype}. Supported data types are numpy.float32 and numpy.float64"
+        )
+
+    return result
 
 
 @require(gribid=int)
@@ -2247,11 +2283,12 @@ def grib_gts_header(flag):
         lib.grib_gts_header_off(context)
 
 
-def grib_get_api_version():
+def grib_get_api_version(vformat=str):
     """
     @brief Get the API version.
 
-    Returns the version of the API as a string in the format "major.minor.revision".
+    Returns the version of the API as a string in the format "major.minor.revision"
+    or as an integer (10000*major + 100*minor + revision)
     """
 
     def div(v, d):
@@ -2261,11 +2298,14 @@ def grib_get_api_version():
         raise RuntimeError("Could not load the ecCodes library!")
 
     v = lib.grib_get_api_version()
-    v, revision = div(v, 100)
-    v, minor = div(v, 100)
-    major = v
 
-    return "%d.%d.%d" % (major, minor, revision)
+    if vformat is str:
+        v, revision = div(v, 100)
+        v, minor = div(v, 100)
+        major = v
+        return "%d.%d.%d" % (major, minor, revision)
+    else:
+        return v
 
 
 __version__ = grib_get_api_version()
@@ -2492,6 +2532,25 @@ def codes_bufr_key_is_header(msgid, key):
     return value
 
 
+@require(msgid=int)
+def codes_bufr_key_is_coordinate(msgid, key):
+    """
+    @brief Check if the BUFR key corresponds to a coordinate descriptor.
+
+    If the data section has not been unpacked, then passing in a key from
+    the data section will throw KeyValueNotFoundError.
+
+    @param msgid      id of the BUFR message loaded in memory
+    @param key        key name
+    @return           1->coordinate, 0->not coordinate
+    @exception CodesInternalError
+    """
+    h = get_handle(msgid)
+    err, value = err_last(lib.codes_bufr_key_is_coordinate)(h, key.encode(ENC))
+    GRIB_CHECK(err)
+    return value
+
+
 def codes_extract_offsets(filepath, product_kind, is_strict=True):
     """
     @brief Message offset extraction
