@@ -38,11 +38,13 @@ def get_sample_fullpath(sample):
 # ---------------------------------------------
 def test_codes_definition_path():
     df = eccodes.codes_definition_path()
+    print(f"\n\teccodes.codes_definition_path returned {df}")
     assert df is not None
 
 
 def test_codes_samples_path():
     sp = eccodes.codes_samples_path()
+    print(f"\n\teccodes.codes_samples_path returned {sp}")
     assert sp is not None
 
 
@@ -54,9 +56,21 @@ def test_codes_set_samples_path():
     eccodes.codes_set_samples_path(eccodes.codes_samples_path())
 
 
+def test_api_version():
+    vs = eccodes.codes_get_api_version()
+    assert type(vs) == str
+    assert len(vs) > 0
+    assert vs == eccodes.codes_get_api_version(str)
+    vi = eccodes.codes_get_api_version(int)
+    assert type(vi) == int
+    assert vi > 20000
+    print(vi)
+
+
 def test_version_info():
     vinfo = eccodes.codes_get_version_info()
     assert len(vinfo) == 2
+    print(vinfo)
 
 
 def test_codes_is_defined():
@@ -253,16 +267,64 @@ def test_grib_get_error():
 
 
 def test_grib_get_array():
-    gid = eccodes.codes_grib_new_from_samples("reduced_gg_pl_160_grib1")
+    gid = eccodes.codes_grib_new_from_samples("reduced_gg_pl_160_grib2")
     pl = eccodes.codes_get_array(gid, "pl")
     assert pl[0] == 18
     pli = eccodes.codes_get_array(gid, "pl", int)
     assert np.array_equal(pl, pli)
     pls = eccodes.codes_get_array(gid, "centre", str)
     assert pls == ["ecmf"]
+    dvals = eccodes.codes_get_array(gid, "values")
+    assert len(dvals) == 138346
+    assert type(dvals[0]) == np.float64
     eccodes.codes_release(gid)
 
 
+def _test_grib_get_array_single_precision():
+    gid = eccodes.codes_grib_new_from_samples("reduced_gg_pl_160_grib2")
+
+    dvals = eccodes.codes_get_array(gid, "values", ktype=float)
+    assert type(dvals[0]) == np.float64
+    fvals = eccodes.codes_get_array(gid, "values", ktype=np.float32)
+    assert type(fvals[0]) == np.float32
+    fvals = eccodes.codes_get_float_array(gid, "values")
+    assert type(fvals[0]) == np.float32
+    dvals = eccodes.codes_get_values(gid)
+    assert type(dvals[0]) == np.float64
+    fvals = eccodes.codes_get_values(gid, np.float32)
+    assert type(fvals[0]) == np.float32
+
+    eccodes.codes_release(gid)
+
+
+def test_grib_gaussian_latitudes():
+    orders = [256, 1280]
+    # Latitude of the first element (nearest the north pole)
+    expected_lats = [89.731148, 89.946187]
+    for _order, _lat in zip(orders, expected_lats):
+        lats = eccodes.codes_get_gaussian_latitudes(_order)
+        assert len(lats) == 2 * _order
+        assert math.isclose(lats[0], _lat, abs_tol=0.00001)
+
+
+def test_grib_latitudes_longitudes():
+    gid = eccodes.codes_grib_new_from_samples("reduced_gg_pl_160_grib2")
+    lats = eccodes.codes_get_array(gid, "latitudes")
+    assert len(lats) == 138346
+    assert math.isclose(lats[0], 89.570089, abs_tol=0.00001)
+    lats = eccodes.codes_get_array(gid, "distinctLatitudes")
+    assert len(lats) == 320
+    assert math.isclose(lats[0], 89.570089, abs_tol=0.00001)
+    assert math.isclose(lats[319], -89.570089, abs_tol=0.00001)
+
+    lons = eccodes.codes_get_array(gid, "longitudes")
+    assert len(lons) == 138346
+    assert math.isclose(lons[138345], 340.00, abs_tol=0.00001)
+    lons = eccodes.codes_get_array(gid, "distinctLongitudes")
+    assert len(lons) == 4762
+    assert math.isclose(lons[4761], 359.4375, abs_tol=0.00001)
+
+
 def test_grib_get_message_size():
     gid = eccodes.codes_grib_new_from_samples("GRIB2")
     assert eccodes.codes_get_message_size(gid) == 179
@@ -487,6 +549,21 @@ def test_grib_set_float_array():
         assert (eccodes.codes_get_values(gid) == 1.0).all()
 
 
+def test_grib_set_2d_array():
+    gid = eccodes.codes_grib_new_from_samples("GRIB2")
+    num_vals = eccodes.codes_get(gid, "numberOfValues")
+    assert num_vals == 496
+    vals2d = np.array([[11, 2, 3], [4, 15, -6]], np.float64)
+    eccodes.codes_set_double_array(gid, "values", vals2d)
+    num_vals = eccodes.codes_get(gid, "numberOfValues")
+    assert num_vals == 6
+    vals = eccodes.codes_get_double_array(gid, "values")
+    assert vals[0] == 11.0
+    assert vals[1] == 2.0
+    assert vals[4] == 15.0
+    assert vals[5] == -6.0
+
+
 def test_grib_set_np_int64():
     gid = eccodes.codes_grib_new_from_samples("regular_gg_sfc_grib2")
     eccodes.codes_set(gid, "productDefinitionTemplateNumber", 1)
@@ -504,7 +581,7 @@ def test_gribex_mode():
 
 def test_grib_new_from_samples_error():
     with pytest.raises(eccodes.FileNotFoundError):
-        eccodes.codes_new_from_samples("poopoo", eccodes.CODES_PRODUCT_GRIB)
+        eccodes.codes_new_from_samples("nonExistentSample", eccodes.CODES_PRODUCT_GRIB)
 
 
 def test_grib_new_from_file_error(tmp_path):
@@ -594,11 +671,20 @@ def test_grib_uuid_get_set():
     # ECC-1167
     gid = eccodes.codes_grib_new_from_samples("GRIB2")
     eccodes.codes_set(gid, "gridType", "unstructured_grid")
-    uuid = eccodes.codes_get_string(gid, "uuidOfHGrid")
+    key = "uuidOfHGrid"
+    ntype = eccodes.codes_get_native_type(gid, key)
+    assert ntype == bytes
+
+    uuid = eccodes.codes_get_string(gid, key)
     assert uuid == "00000000000000000000000000000000"
-    eccodes.codes_set_string(gid, "uuidOfHGrid", "DEfdBEef10203040b00b1e50001100FF")
-    uuid = eccodes.codes_get_string(gid, "uuidOfHGrid")
+    eccodes.codes_set_string(gid, key, "DEfdBEef10203040b00b1e50001100FF")
+    uuid = eccodes.codes_get(gid, key, str)
     assert uuid == "defdbeef10203040b00b1e50001100ff"
+    uuid = eccodes.codes_get(gid, key)
+    assert uuid == "defdbeef10203040b00b1e50001100ff"
+
+    uuid_arr = eccodes.codes_get_array(gid, key)
+    assert uuid_arr == ["defdbeef10203040b00b1e50001100ff"]
     eccodes.codes_release(gid)
 
 
@@ -763,11 +849,23 @@ def test_codes_bufr_key_is_header():
         eccodes.codes_bufr_key_is_header(bid, "satelliteSensorIndicator")
 
     eccodes.codes_set(bid, "unpack", 1)
-
     assert not eccodes.codes_bufr_key_is_header(bid, "satelliteSensorIndicator")
     assert not eccodes.codes_bufr_key_is_header(bid, "#6#brightnessTemperature")
 
 
+def _test_codes_bufr_key_is_coordinate():
+    bid = eccodes.codes_bufr_new_from_samples("BUFR4")
+    assert not eccodes.codes_bufr_key_is_coordinate(bid, "edition")
+
+    with pytest.raises(eccodes.KeyValueNotFoundError):
+        eccodes.codes_bufr_key_is_coordinate(bid, "latitude")
+
+    eccodes.codes_set(bid, "unpack", 1)
+    assert eccodes.codes_bufr_key_is_coordinate(bid, "latitude")
+    assert eccodes.codes_bufr_key_is_coordinate(bid, "#14#timePeriod")
+    assert not eccodes.codes_bufr_key_is_coordinate(bid, "dewpointTemperature")
+
+
 def test_bufr_extract_headers():
     fpath = get_sample_fullpath("BUFR4_local.tmpl")
     if fpath is None:
@@ -796,16 +894,6 @@ def test_bufr_dump(tmp_path):
 # ---------------------------------------------
 # Experimental features
 # ---------------------------------------------
-def test_codes_get_gaussian_latitudes():
-    orders = [256, 1280]
-    # Latitude of the first element (nearest the north pole)
-    expected_lats = [89.731148, 89.946187]
-    for _order, _lat in zip(orders, expected_lats):
-        lats = eccodes.codes_get_gaussian_latitudes(_order)
-        assert len(lats) == 2 * _order
-        assert math.isclose(lats[0], _lat, abs_tol=0.00001)
-
-
 def test_grib_nearest2():
     if "codes_grib_nearest_new" not in dir(eccodes):
         return
