@@ -70,7 +70,7 @@ def test_message_set_dict_with_checks():
         message = next(reader)
         message.set(
             {
-                "centre": "ecmf",
+                "centre": 98,
                 "numberOfValues": 10,
                 "shortName": "z",
             }
@@ -80,6 +80,7 @@ def test_message_set_dict_with_checks():
         with pytest.raises(ValueError):
             message.set("stepRange", "0-12")
         message.set({"stepType": "max", "stepRange": "0-12"})
+        message.set("iDirectionIncrementInDegrees", 1.5)
 
 
 def test_message_set_dict_no_checks():
